@@ -1,4 +1,4 @@
-/* $Id: files.c 4317 2008-08-30 21:00:00Z astyanax $ */
+/* $Id: files.c 4345 2008-10-22 22:11:46Z astyanax $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -2028,6 +2028,15 @@ bool do_writeout(bool exiting)
 			    continue;
 		    }
 		}
+#ifndef NANO_TINY
+		if (openfile->current_stat && openfile->current_stat->st_mtime < st.st_mtime) {
+		    i = do_yesno_prompt(FALSE,
+			_("File was modified since you opened it, continue saving ? "));
+		    if (i == 0 || i == -1)
+			continue;
+		}
+#endif
+
 	    }
 
 	    /* Convert newlines to nulls, just before we save the
