@@ -1,4 +1,4 @@
-/* $Id: nano.h 4328 2008-09-21 23:02:30Z astyanax $ */
+/* $Id: nano.h 4340 2008-10-14 04:34:56Z astyanax $ */
 /**************************************************************************
  *   nano.h                                                               *
  *                                                                        *
@@ -170,7 +170,7 @@ typedef enum {
 }  function_type;
 
 typedef enum {
-    ADD, DEL, REPLACE, SPLIT, UNSPLIT, CUT, CUTTOEND, UNCUT, INSERT, OTHER
+    ADD, DEL, REPLACE, SPLIT, UNSPLIT, CUT, UNCUT, INSERT, OTHER
 } undo_type;
 
 /* Structure types. */
@@ -276,8 +276,6 @@ typedef struct undo {
 	/* copy copy copy */
     ssize_t mark_begin_x;
 	/* Another shadow variable */
-    ssize_t linescut;
-	/* How many lines we cut on a straight non-marked non-to-end cut */
     struct undo *next;
 } undo;
 
