@@ -1,4 +1,4 @@
-/* $Id: rcfile.c 4328 2008-09-21 23:02:30Z astyanax $ */
+/* $Id: rcfile.c 4342 2008-10-14 19:55:34Z astyanax $ */
 /**************************************************************************
  *   rcfile.c                                                             *
  *                                                                        *
@@ -723,7 +723,7 @@ void parse_colors(char *ptr, bool icase)
 /* Parse the headers (1st line) of the file which may influence the regex used. */
 void parse_headers(char *ptr)
 {
-    char *h, *regstr;
+    char *regstr;
 
     assert(ptr != NULL);
 
@@ -743,8 +743,6 @@ void parse_headers(char *ptr)
     while (ptr != NULL && *ptr != '\0') {
 	exttype *newheader;
 	    /* The new color structure. */
-	bool cancelled = FALSE;
-	    /* The start expression was bad. */
 
 	if (*ptr != '"') {
 	    rcfile_error(
