@@ -1,4 +1,4 @@
-/* $Id: text.c 4327 2008-09-16 21:35:19Z astyanax $ */ 
+/* $Id: text.c 4342 2008-10-14 19:55:34Z astyanax $ */ 
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
@@ -388,7 +388,7 @@ void undo_cut(undo *u)
 /* Re-do a cut, or undo an uncut */
 void redo_cut(undo *u) {
     int i;
-    filestruct *t;
+    filestruct *t, *c;
 
 	do_gotolinecolumn(u->lineno, u->begin+1, FALSE, FALSE, FALSE, FALSE);
 	openfile->mark_set = u->mark_set;
@@ -405,14 +405,12 @@ void redo_cut(undo *u) {
 	    /* Here we have a regular old potentially multi-line ^K cut.  We'll
 		need to trick nano into thinking it's a marked cut to cut more
 		than one line again */
-#ifdef DEBUG
-	    fprintf(stderr, "Undoing multi-^K cut, u->linescut = %d\n", u->linescut);
-#endif
-	    for (i = 0, t = openfile->current; i < u->linescut; i++) {
+	    for (c = u->cutbuffer, t = openfile->current; c->next != NULL && t->next != NULL; ) {
 
 #ifdef DEBUG
 	    fprintf(stderr, "Advancing, lineno  = %d, data = \"%s\"\n", t->lineno, t->data);
 #endif
+		c = c->next;
 		t = t->next;
 	    }
 	    openfile->mark_begin = t;
@@ -505,7 +503,6 @@ void do_undo(void)
 	renumber(f);
 	break;
     case CUT:
-    case CUTTOEND:
 	undidmsg = _("text cut");
         undo_cut(u);
 	break;
@@ -552,8 +549,7 @@ void do_redo(void)
 {
     undo *u = openfile->undotop;
     filestruct *f = openfile->current, *t;
-    filestruct *oldcutbuffer = cutbuffer, *oldcutbottom = cutbottom;
-    int len = 0, i;
+    int len = 0;
     char *undidmsg, *data;
 
     for (; u != NULL && u->next != openfile->current_undo; u = u->next)
@@ -629,7 +625,6 @@ void do_redo(void)
 	renumber(f);
 	break;
     case CUT:
-    case CUTTOEND:
 	undidmsg = _("text cut");
 	redo_cut(u);
 	break;
@@ -819,9 +814,10 @@ bool execute_command(const char *command)
 /* Add a new undo struct to the top of the current pile */
 void add_undo(undo_type current_action)
 {
-    undo *u, *cutu;
+    undo *u;
     char *data;
     openfilestruct *fs = openfile;
+    static undo *last_cutu = NULL; /* Last thing we cut to set up the undo for uncut */
 
     /* Ugh, if we were called while cutting not-to-end, non-marked and on the same lineno,
        we need to  abort here */
@@ -855,8 +851,8 @@ void add_undo(undo_type current_action)
     u->mark_set = 0;
     u->mark_begin_lineno = 0;
     u->mark_begin_x = 0;
-    u->linescut = 0;
     u->xflags = 0;
+    u->to_end = FALSE;
 
     switch (u->type) {
     /* We need to start copying data into the undo buffer or we wont be able
@@ -889,29 +885,21 @@ void add_undo(undo_type current_action)
 	u->strdata = data;
 	break;
     case CUT:
-    case CUTTOEND:
 	u->mark_set = openfile->mark_set;
 	if (u->mark_set) {
 	    u->mark_begin_lineno = openfile->mark_begin->lineno;
 	    u->mark_begin_x = openfile->mark_begin_x;
 	}
-	u->to_end = (current_action == CUTTOEND);
+	u->to_end = (ISSET(CUT_TO_END)) ? TRUE : FALSE;
+	last_cutu = u;
 	break;
     case UNCUT:
-	for (cutu = u; cutu != NULL && cutu->type != CUT; cutu = cutu->next)
-	    ;
-	if (cutu->type == CUT) {
-	    u->cutbuffer = cutu->cutbuffer;
-	    u->cutbottom = cutu->cutbottom;
-	    if (!cutu->mark_set)
-		u->linescut = cutu->linescut;
-	    else {
-		filestruct *c;
-		for (c = u->cutbuffer; c != NULL; c = c->next)
-		    u->linescut++;
-	    }
-	} else
+	if (!last_cutu)
 	    statusbar(_("Internal error: can't setup uncut.  Please save your work."));
+	else if (last_cutu->type == CUT) {
+	    u->cutbuffer = last_cutu->cutbuffer;
+	    u->cutbottom = last_cutu->cutbottom;
+	}
 	break;
     case OTHER:
 	statusbar(_("Internal error: unknown type.  Please save your work."));
@@ -950,7 +938,7 @@ void update_undo(undo_type action)
     /* Change to an add if we're not using the same undo struct
        that we should be using */
     if (action != fs->last_action
-	|| (action != CUT && action != CUTTOEND && action != INSERT
+	|| (action != CUT && action != INSERT
 	    && openfile->current->lineno != fs->current_undo->lineno)) {
         add_undo(action);
 	return;
@@ -1015,12 +1003,14 @@ void update_undo(undo_type action)
 #endif
 	break;
     case CUT:
-    case CUTTOEND:
+	if (!cutbuffer)
+	    break;
 	if (u->cutbuffer)
 	    free(u->cutbuffer);
 	u->cutbuffer = copy_filestruct(cutbuffer);
-	u->cutbottom = cutbottom;
-	u->linescut++;
+        /* Compute cutbottom for the uncut using out copy */
+        for (u->cutbottom = u->cutbuffer; u->cutbottom->next != NULL; u->cutbottom = u->cutbottom->next)
+            ;
 	break;
     case REPLACE:
     case UNCUT:
